/**
  *  \file client/widgets/colorselect.h
  *  \brief WColorSelector widget
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_COLORSELECT_H
#define PCC_V2_CLIENT_WIDGETS_COLORSELECT_H

#include "ui/ui.h"

/** Color selector widget. Allows selection of a user color. Note that
    user colors are allowed to be zero (yielding invisible objects). 
    Hence we allow color 0 in our program interfaces, but we do not
    allow the user to select color 0. */
class WColorSelector : public UIWidget {
    /** User color index (not a palette index!). */
    int user_color;

    void moveBy(int delta);
    int  getFrameSize() const;
 public:
    WColorSelector();
    ~WColorSelector();

    void setColor(int user_color);
    int  getColor() const;

    void getLayoutInfo(LayoutInfo& info);
    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& e, bool second_pass);

    enum {
        rCancel,
        rOK,
        rAdjacent
    };
    int doStandardDialog(string_t title, bool offer_adjacent);
};

#endif
